@@ -22,7 +22,7 @@ using namespace Kontact;
 #include <QHBoxLayout>
 #include <QStandardItemModel>
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMKontactSummaryFactory, "kontactconfig.json", registerPlugin<KcmKontact>();)
+K_PLUGIN_CLASS_WITH_JSON(KcmKontact, "data/kontactconfig.json")
 KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
     , mPluginCombo(new QComboBox(parent))
@@ -61,9 +61,10 @@ KcmKontact::KcmKontact(QWidget *parent, const QVariantList &args)
 void KcmKontact::load()
 {
     const KConfigGroup grp(Prefs::self()->config(), "Plugins");
-    const QVector<KPluginMetaData> pluginMetaDatas = KPluginMetaData::findPlugins(QStringLiteral("kontact5"), [](const KPluginMetaData &data) {
-        return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
-    });
+    const QVector<KPluginMetaData> pluginMetaDatas =
+        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kontact"), [](const KPluginMetaData &data) {
+            return data.rawData().value(QStringLiteral("X-KDE-KontactPluginVersion")).toInt() == KONTACT_PLUGIN_VERSION;
+        });
 
     int activeComponent = 0;
     mPluginCombo->clear();
@@ -106,18 +107,4 @@ void KcmKontact::save()
     KCModule::save();
 }
 
-const KAboutData *KcmKontact::aboutData() const
-{
-    auto about = new KAboutData(QStringLiteral("kontactconfig"),
-                                i18nc("@title", "KDE Kontact"),
-                                QString(),
-                                QString(),
-                                KAboutLicense::GPL,
-                                i18nc("@info:credit", "(c), 2003 Cornelius Schumacher"));
-
-    about->addAuthor(i18nc("@info:credit", "Cornelius Schumacher"), i18nc("@info:credit", "Developer"), QStringLiteral("schumacher@kde.org"));
-    about->addAuthor(i18nc("@info:credit", "Tobias Koenig"), i18nc("@info:credit", "Developer"), QStringLiteral("tokoe@kde.org"));
-
-    return about;
-}
 #include "kcmkontact.moc"
